<?php


class RSPW_Product_Attribute_Rule implements RSPW_Rule {


	/**
	 * @param array $rule
	 * @param array $package
	 *
	 * @return boolean
	 */
	public function validate( $rule, $package ) {
		$rule_attribute_id    = $rule['value_product_attribute'];
		$attribute            = wc_get_attribute( $rule_attribute_id );
		$rule_attribute_value = $rule['value_product_attribute_value'];

		$operator = RSPW_Operators_Factory::make( $rule['operator'] );

		foreach ( $package as $item_id => $content ) {
            if (!isset($content['data'])) continue;
			/** @var WC_Product $product */
			$product                 = $content['data'];
			$product_attribute_value = $product->get_attribute( $attribute->name );
			if ( $operator->match( $rule_attribute_value, $product_attribute_value ) ) {
				return true;
			}
		}

		return false;
	}

	/**
	 * @return array
	 */
	public function get_operators_labels() {
		return array(
			RSPW_Operators_Factory::OPERATOR_IS     => __( 'is', 'restricted-shipping-and-payment-for-woocommerce' ),
			RSPW_Operators_Factory::OPERATOR_IS_NOT => __( 'is not', 'restricted-shipping-and-payment-for-woocommerce' ),
		);
	}

	/**
	 * @return array
	 */
	public function get_meta_box_fields() {
		return array(
			array(
				'name'             => __( 'Product Attribute', 'restricted-shipping-and-payment-for-woocommerce' ),
				'desc'             => __( 'Select product attribute', 'restricted-shipping-and-payment-for-woocommerce' ),
				'id'               => 'value_product_attribute',
				'type'             => 'select',
				'show_option_none' => false,
				'options'          => $this->get_product_attributes(),
				'classes'          => 'value_field product_attribute',
			),
			array(
				'name'    => __( 'Attribute Value', 'restricted-shipping-and-payment-for-woocommerce' ),
				'id'      => 'value_product_attribute_value',
				'type'    => 'text_small',
				'classes' => 'value_field product_attribute',
			),
		);
	}

	/**
	 * @return array
	 */
	private function get_product_attributes() {
		$product_attributes   = array();
		$attribute_taxonomies = wc_get_attribute_taxonomies();

		foreach ( $attribute_taxonomies as $attribute ) {
			$product_attributes[ intval( $attribute->attribute_id ) ] = $attribute->attribute_label;
		}
		return $product_attributes;
	}
}
