<?php


class RSPW_Product_Category_Rule implements RSPW_Rule {


	/**
	 * @param array $rule
	 * @param array $package
	 *
	 * @return boolean
	 */
	public function validate( $rule, $package ) {
		$rule_product_category = $rule['value_product_category'];
		$operator              = RSPW_Operators_Factory::make( $rule['operator'] );

		$cart_categories = array();

		foreach ( $package as $item_id => $content ) {
            if (!isset($content['data'])) continue;
			/** @var WC_Product $product */
			$product = $content['data'];
			$terms   = get_the_terms( $product->get_id(), 'product_cat' );
			if ( ! $terms ) {
				continue;
			}

			$product_categories = array_map(
				function ( $term ) {
					return $term->term_id;
				},
				$terms
			);

			$cart_categories = array_merge( $cart_categories, $product_categories );
		}

		if ( $operator->match( $rule_product_category, $cart_categories ) ) {
			return true;
		}

		return false;
	}

	/**
	 * @return array
	 */
	public function get_operators_labels() {
		return array(
			RSPW_Operators_Factory::OPERATOR_IN     => __( 'in', 'restricted-shipping-and-payment-for-woocommerce' ),
			RSPW_Operators_Factory::OPERATOR_NOT_IN => __( 'not in', 'restricted-shipping-and-payment-for-woocommerce' ),
		);
	}

	/**
	 * @return array
	 */
	public function get_meta_box_fields() {
		return array(
			array(
				'name'             => __( 'Product Categories', 'restricted-shipping-and-payment-for-woocommerce' ),
				'desc'             => __( 'Select product category/ies', 'restricted-shipping-and-payment-for-woocommerce' ),
				'id'               => 'value_product_category',
				'type'             => 'pw_multiselect',
				'show_option_none' => false,
				'options'          => $this->get_product_categories(),
				'classes'          => 'value_field product_category',
			),
		);
	}

	/**
	 * @return array
	 */
	private function get_product_categories() {
		$arguments = array(
			'taxonomy'   => 'product_cat',
			'orderby'    => 'name',
			'order'      => 'desc',
			'hide_empty' => false,
		);

		$product_categories = get_terms( $arguments );

		$categories = array();
		/** @var WP_Term $category */
		foreach ( $product_categories as $category ) {
			$categories[ $category->term_id ] = $category->name;
		}

		return $categories;
	}
}
