<?php


class RSPW_Rules_Factory {

	const RULE_SHIPPING_CLASS    = 'shipping_class';
	const RULE_COUPON_CODE       = 'coupon_code';
	const RULE_CART_TOTAL        = 'cart_total';
	const RULE_PACKAGE_WEIGHT    = 'package_weight';
	const RULE_SHIPPING_COUNTRY  = 'shipping_country';
	const RULE_BILLING_COUNTRY   = 'billing_country';
	const RULE_CUSTOMER          = 'customer';
	const RULE_CUSTOMER_ROLE     = 'customer_role';
	const RULE_CITY              = 'city';
	const RULE_POSTCODE          = 'postcode';
	const RULE_STATE             = 'state';
	const RULE_PRODUCT_CATEGORY  = 'product_category';
	const RULE_PRODUCT_TAG       = 'product_tag';
	const RULE_PRODUCT_ATTRIBUTE = 'product_attribute';
	const RULE_DOWNLOADABLE      = 'downloadable';
	const RULE_VIRTUAL           = 'virtual';
	const RULE_QUANTITY          = 'quantity';
	const RULE_PAYMENT_GATEWAY          = 'payment_gateway';
	const RULE_SHIPPING_METHOD          = 'shipping_method';
	const RULE_TIME_OF_DAY          = 'time_of_day';

	/**
	 * @param string $rule
	 *
	 * @return RSPW_Rule|null
	 */
	public static function make( $rule ) {
		$available_rules = self::available_rules();

		if ( isset( $available_rules[ $rule ] ) ) {
			return new $available_rules[ $rule ]['class']();
		}

		return null;
	}

	public static function available_rules() {
		return array(
			self::RULE_SHIPPING_CLASS    => array(
				'class' => RSPW_Shipping_Class_Rule::class,
				'label' => __( 'Shipping Class', 'restricted-shipping-and-payment-for-woocommerce' ),
			),
			self::RULE_COUPON_CODE       => array(
				'class' => RSPW_Coupon_Code_Rule::class,
				'label' => __( 'Coupon Code', 'restricted-shipping-and-payment-for-woocommerce' ),
			),
			self::RULE_CART_TOTAL        => array(
				'class' => RSPW_Cart_Total_Rule::class,
				'label' => __( 'Cart Total', 'restricted-shipping-and-payment-for-woocommerce' ),
			),
			self::RULE_PACKAGE_WEIGHT    => array(
				'class' => RSPW_Package_Weight_Rule::class,
				'label' => __( 'Package Weight', 'restricted-shipping-and-payment-for-woocommerce' ),
			),
			self::RULE_SHIPPING_COUNTRY  => array(
				'class' => RSPW_Shipping_Country_Rule::class,
				'label' => __( 'Shipping Country', 'restricted-shipping-and-payment-for-woocommerce' ),
			),
			self::RULE_BILLING_COUNTRY   => array(
				'class' => RSPW_Billing_Country_Rule::class,
				'label' => __( 'Billing Country', 'restricted-shipping-and-payment-for-woocommerce' ),
			),
			self::RULE_CUSTOMER          => array(
				'class' => RSPW_Customer_Rule::class,
				'label' => __( 'Customer', 'restricted-shipping-and-payment-for-woocommerce' ),
			),
			self::RULE_CUSTOMER_ROLE     => array(
				'class' => RSPW_Customer_Role_Rule::class,
				'label' => __( 'Customer Role', 'restricted-shipping-and-payment-for-woocommerce' ),
			),
			self::RULE_POSTCODE          => array(
				'class' => RSPW_Postcode_Rule::class,
				'label' => __( 'Postcode', 'restricted-shipping-and-payment-for-woocommerce' ),
			),
			self::RULE_CITY              => array(
				'class' => RSPW_City_Rule::class,
				'label' => __( 'City', 'restricted-shipping-and-payment-for-woocommerce' ),
			),
			self::RULE_STATE             => array(
				'class' => RSPW_State_Rule::class,
				'label' => __( 'State', 'restricted-shipping-and-payment-for-woocommerce' ),
			),
			self::RULE_PRODUCT_CATEGORY  => array(
				'class' => RSPW_Product_Category_Rule::class,
				'label' => __( 'Product Category', 'restricted-shipping-and-payment-for-woocommerce' ),
			),
			self::RULE_PRODUCT_TAG       => array(
				'class' => RSPW_Product_Tag_Rule::class,
				'label' => __( 'Product Tag', 'restricted-shipping-and-payment-for-woocommerce' ),
			),
			self::RULE_PRODUCT_ATTRIBUTE => array(
				'class' => RSPW_Product_Attribute_Rule::class,
				'label' => __( 'Product Attribute', 'restricted-shipping-and-payment-for-woocommerce' ),
			),
			self::RULE_DOWNLOADABLE      => array(
				'class' => RSPW_Downloadable_Rule::class,
				'label' => __( 'Downloadable', 'restricted-shipping-and-payment-for-woocommerce' ),
			),
			self::RULE_VIRTUAL           => array(
				'class' => RSPW_Virtual_Rule::class,
				'label' => __( 'Virtual', 'restricted-shipping-and-payment-for-woocommerce' ),
			),
			self::RULE_QUANTITY          => array(
				'class' => RSPW_Product_Quantity_Rule::class,
				'label' => __( 'Total Cart Quantity', 'restricted-shipping-and-payment-for-woocommerce' ),
			),
            self::RULE_PAYMENT_GATEWAY   => array(
                'class' => RSPW_Payment_Gateway_Rule::class,
                'label' => __( 'Payment Gateway', 'restricted-shipping-and-payment-for-woocommerce' ),
            ),
            self::RULE_SHIPPING_METHOD   => array(
                'class' => RSPW_Shipping_Method_Rule::class,
                'label' => __( 'Shipping Method', 'restricted-shipping-and-payment-for-woocommerce' ),
            ),
            self::RULE_TIME_OF_DAY   => array(
                'class' => RSPW_Time_Of_Day_Rule::class,
                'label' => __( 'Time of Day', 'restricted-shipping-and-payment-for-woocommerce' ),
            ),

		);
	}
}
