<?php


class RSPW_Shipping_Class_Rule implements RSPW_Rule {


	/**
	 * @param array $rule
	 * @param array $package
	 *
	 * @return boolean
	 */
	public function validate( $rule, $package ) {
		$rule_shipping_class = isset( $rule['value_shipping_class'] ) ? $rule['value_shipping_class'] : null;

		if ( is_null( $rule_shipping_class ) ) {
			return false;
		}

		$rule_operator = ( isset( $rule['operator'] ) ) ? $rule['operator'] : null;

		if ( is_null( $rule_operator ) ) {
			return false;
		}

		$operator              = RSPW_Operators_Factory::make( $rule['operator'] );
		$cart_shipping_classes = array();
		foreach ( $package as $item_id => $content ) {
            if (!isset($content['data'])) continue;
			/** @var WC_Product $product */
			$product                 = $content['data'];
			$cart_shipping_classes[] = $product->get_shipping_class();
		}

		return $operator->match( $rule_shipping_class, $cart_shipping_classes );
	}

	/**
	 * @return array
	 */
	public function get_operators_labels() {
		return array(
			RSPW_Operators_Factory::OPERATOR_IN     => __( 'included in the order', 'restricted-shipping-and-payment-for-woocommerce' ),
			RSPW_Operators_Factory::OPERATOR_NOT_IN => __( 'not included in the order', 'restricted-shipping-and-payment-for-woocommerce' ),
		);
	}

	public function get_meta_box_fields() {
		return array(
			array(
				'name'             => __( 'Shipping Classes', 'restricted-shipping-and-payment-for-woocommerce' ),
				'desc'             => __( 'Select shipping class/es', 'restricted-shipping-and-payment-for-woocommerce' ),
				'id'               => 'value_shipping_class',
				'type'             => 'pw_multiselect',
				'show_option_none' => false,
				'options'          => $this->get_shipping_classes(),
				'classes'          => 'value_field shipping_class',
			),
		);
	}

	/**
	 * @return array
	 */
	private function get_shipping_classes() {
		$classes          = array();
		$shipping_classes = WC()->shipping()->get_shipping_classes();
		foreach ( $shipping_classes as $shipping_class ) {
			$classes[ $shipping_class->slug ] = $shipping_class->name;
		}
		return $classes;
	}
}
