<?php


class RSPW_Shipping_Method_Rule implements RSPW_Rule
{

    public function validate($rule, $package)
    {

        $chosen_shipping_methods = WC()->session->get('chosen_shipping_methods');

        if (count($chosen_shipping_methods) === 0) {
            return false;
        }

        $chosen_shipping_method = $this->get_shipping_method_key($chosen_shipping_methods[0]);

        if (!isset($rule['value_shipping_method'])) {
            return false;
        }

        if (count($rule['value_shipping_method']) === 0) {
            return false;
        }

        $rule_shipping_methods = [];
        foreach ($rule['value_shipping_method'] as $shipping_method) {
            $rule_shipping_methods[] = $this->get_shipping_method_key($shipping_method);
        }

        return in_array($chosen_shipping_method, $rule_shipping_methods);
    }

    public function get_operators_labels()
    {
        return [
            RSPW_Operators_Factory::OPERATOR_IS     => __( 'is', 'restricted-shipping-and-payment-for-woocommerce' ),
        ];
    }

    public function get_meta_box_fields()
    {
        return array(
            array(
                'name'             => __( 'Shipping Method', 'restricted-shipping-and-payment-for-woocommerce' ),
                'desc'             => __( 'Select shipping method/s', 'restricted-shipping-and-payment-for-woocommerce' ),
                'id'               => 'value_shipping_method',
                'type'             => 'pw_multiselect',
                'show_option_none' => false,
                'options'          => RSPW::get_shipping_methods(),
                'classes'          => 'value_field shipping_method',
            ),
        );
    }

    private function get_shipping_method_key($chosen_method)
    {
        $chosen_shipping_methods = explode(':', $chosen_method);
        return $chosen_shipping_methods[0];
    }

}
