<?php


class RSPW_State_Rule implements RSPW_Rule {


	/**
	 * @param array $rule
	 * @param array $package
	 *
	 * @return boolean
	 */
	public function validate( $rule, $package ) {

        if (!isset($package['destination'])) {
            return false;
        }

		$state            = $package['destination']['state'];
		$country          = $package['destination']['country'];
		$state_to_compare = $country . '_' . $state;
		$operator         = RSPW_Operators_Factory::make( $rule['operator'] );
		return $operator->match( $state_to_compare, $rule['value_states'] );
	}

	/**
	 * @return array
	 */
	public function get_operators_labels() {
		return array(
			RSPW_Operators_Factory::OPERATOR_IS     => __( 'is', 'restricted-shipping-and-payment-for-woocommerce' ),
			RSPW_Operators_Factory::OPERATOR_IS_NOT => __( 'is not', 'restricted-shipping-and-payment-for-woocommerce' ),
		);
	}

	/**
	 * @return array
	 */
	public function get_meta_box_fields() {
		return array(
			array(
				'name'    => __( 'State\s', 'restricted-shipping-and-payment-for-woocommerce' ),
				'id'      => 'value_states',
				'type'    => 'pw_multiselect',
				'classes' => 'value_field state',
				'options' => $this->get_states(),
			),
		);
	}

	private function get_states() {
		$wc_states = ( ( new WC_Countries() )->get_states() );
		$states    = array();
		foreach ( $wc_states as $country => $country_states ) {
			foreach ( $country_states as $state_code => $state ) {
				$states[ $country . '_' . $state_code ] = $state;
			}
		}
		return $states;
	}
}
