<?php

class RSPW_Time_Of_Day_Rule implements RSPW_Rule
{

    public function validate($rule, $package)
    {
        $time_rule = $rule['value_time_of_day'];
        $from = $time_rule['time_from'];
        $to = $time_rule['time_to'];

        $time_now = strtotime( date('H:i:s'));
        $time_from = strtotime($from);
        $time_to = strtotime($to);

        return $this->between($time_now, $time_from, $time_to);
    }

    public function get_operators_labels()
    {
        return [
            RSPW_Operators_Factory::OPERATOR_IS     => __( 'is', 'restricted-shipping-and-payment-for-woocommerce' ),
        ];
    }

    public function get_meta_box_fields()
    {
        return array(
            array(
                'name'             => __( 'Time of Day', 'restricted-shipping-and-payment-for-woocommerce' ),
                'desc'             => __( 'Select time of day', 'restricted-shipping-and-payment-for-woocommerce' ),
                'id'               => 'value_time_of_day',
                'type'             => 'rspw_time_range',
                'classes'          => 'value_field time_of_day',
            ),
        );
    }

    protected function between(float $value, float $from, float $to) :bool
    {
        return $value >= $from && $value <= $to;
    }
}
